@@ -18,7 +18,7 @@ class Submission:
         self.assignment_id = assignment_id
         self.model = model
 
-    def submit(self) -> None:
+    def submit(self, verbose: bool = False, strict: bool = False) -> None:
         provider = klti.LTIProvider(
             input_api_endpoint="https://neuralnet.xopic.de/ltiprovider",
             submission_api_endpoint="https://neuralnet.xopic.de/ltiprovider/submit",
@@ -28,9 +28,18 @@ class Submission:
         submission = klti.Submission(assignment_id=self.assignment_id, model=self.model)
 
         try:
-            provider.submit(submission)
-            print("Erfolgreich abgegeben.")
-            print("Du kannst deine Ergebnisse auf OpenHPI einsehen.")
+            results = provider.submit(submission, verbose=verbose, strict=strict)
+            for assignment_id, result in results.items():
+                print(f"Assignment {assignment_id} erfolgreich abgegeben!")
+                print(
+                    f"Dein Model hat eine Accuracy von {round(result.get('accuracy') * 100, ndigits=1)}% auf unseren Validierungsdaten."
+                )
+                print(
+                    f"Du erhältst {round(result.get('grade') * 100, ndigits=1)}% der Punkte auf dieses Assignment."
+                )
+                print(
+                    f"Falls du bereits eine Abgabe mit höherer Bewertung abgegeben hast, wird automatisch das bessere Ergebnis gewählt."
+                )
         except KerasLTISubmissionBadResponseException as e:
             print(e.message)
         except Exception as e:
